@@ -638,7 +638,7 @@ int dbd_mysql_statement(lua_State *L) {
 
 	dbd_register(L, DBD_MYSQL_STATEMENT,
 	             statement_methods, statement_class_methods,
-	             statement_gc, statement_tostring);
+	             statement_gc, statement_tostring, statement_close);
 
 	return 1;
 }
