@@ -609,7 +609,7 @@ int dbd_oracle_connection(lua_State *L) {
 
 	dbd_register(L, DBD_ORACLE_CONNECTION,
 	             connection_methods, connection_class_methods,
-	             connection_gc, connection_tostring);
+	             connection_gc, connection_tostring, connection_close);
 
 	/* Register Oracle constants in our new metatable */
 	luaL_getmetatable(L, DBD_ORACLE_CONNECTION);
