@@ -463,7 +463,7 @@ int dbd_postgresql_statement(lua_State *L) {
 
 	dbd_register(L, DBD_POSTGRESQL_STATEMENT,
 	             statement_methods, statement_class_methods,
-	             statement_gc, statement_tostring);
+	             statement_gc, statement_tostring, statement_close);
 
 	return 1;
 }
