@@ -262,7 +262,7 @@ static int statement_fetch_impl(lua_State *L, statement_t *statement, int named_
 					LUA_PUSH_ARRAY_NIL(d);
 				}
 			} else if (lua_push == LUA_PUSH_INTEGER) {
-				int val = sqlite3_column_int(statement->stmt, i);
+				long val = sqlite3_column_int64(statement->stmt, i);
 
 				if (named_columns) {
 					LUA_PUSH_ATTRIB_INT(name, val);
@@ -279,11 +279,12 @@ static int statement_fetch_impl(lua_State *L, statement_t *statement, int named_
 				}
 			} else if (lua_push == LUA_PUSH_STRING) {
 				const char *val = (const char *)sqlite3_column_text(statement->stmt, i);
+				int len = sqlite3_column_bytes(statement->stmt, i);
 
 				if (named_columns) {
-					LUA_PUSH_ATTRIB_STRING(name, val);
+					LUA_PUSH_ATTRIB_STRING_BY_LENGTH(name, val, len);
 				} else {
-					LUA_PUSH_ARRAY_STRING(d, val);
+					LUA_PUSH_ARRAY_STRING_BY_LENGTH(d, val, len);
 				}
 			} else if (lua_push == LUA_PUSH_BOOLEAN) {
 				int val = sqlite3_column_int(statement->stmt, i);
@@ -416,7 +417,7 @@ int dbd_sqlite3_statement(lua_State *L) {
 
 	dbd_register(L, DBD_SQLITE_STATEMENT,
 	             statement_methods, statement_class_methods,
-	             statement_gc, statement_tostring);
+	             statement_gc, statement_tostring, statement_close);
 
 	return 1;
 }
